@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '1.56'; # VERSION
+our $DATE = '2015-09-15'; # DATE
+our $VERSION = '1.57'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -504,15 +504,23 @@ sub hook_format_result {
 
     $res->[3]{format_options} = $r->{format_options} if $r->{format_options};
 
+    my $fres;
     if ($res->[3]{is_stream}) {
         $log->tracef("Result is a stream");
         return undef;
     } elsif ($res->[3]{'x.hint.result_binary'} && $format =~ /text/) {
-        $r->{fres} = $res->[2];
+        $fres = $res->[2];
     } else {
         $log->tracef("Formatting output with %s", $format);
-        $r->{fres} = Perinci::Result::Format::format($res, $format);
+        $fres = Perinci::Result::Format::format($res, $format);
     }
+
+    # ux: prefix error message with program name
+    if ($format=~/text/ && $r->{res}[0] =~ /\A[45]/ && defined($r->{res}[1])) {
+        $fres = "$self->{program_name}: $fres";
+    }
+
+    $fres;
 }
 
 sub hook_display_result {
@@ -778,7 +786,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.56 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-09-03.
+This document describes version 1.57 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-09-15.
 
 =head1 SYNOPSIS
 
